<script setup lang="ts">
const outputDefaults = `opt server_output = "./network/server.lua"
opt client_output = "path/to/client/output.lua"`

const outputExample = `opt server_output = "./network/client.luau"
opt client_output = "src/client/zap.luau"`
</script>

# Options

Options are placed at the beginning of Zap config files and allow you to configure the way Zap generates code.

## `server_output` & `client_output`

These two options allow you to configure where Zap will output generated code. If you're not using the CLI these options can be ignored.

The paths are relative to the configuration file and should point to a lua(u) file.

### Default

<CodeBlock :code="outputDefaults" />

### Example

<CodeBlock :code="outputExample" />

## `casing`

This option changes the casing of the API generated by Zap.

Using the `FireAll` function as an example:

| Casing       | Example    |
| ------------ | ---------- |
| `PascalCase` | `FireAll`  |
| `camelCase`  | `fireAll`  |
| `snake_case` | `fire_all` |

::: info
This option does not change the casing of your event or type names. It only changes the casing of generated API functions.
:::

### Default

`PascalCase`

### Options

- `"camelCase"`
- `"PascalCase"`
- `"snake_case"`

### Example

<CodeBlock code='opt casing = "camelCase"' />

## `write_checks`

This option determines if Zap should check types when writing data to the network. This is useful for development and debugging, but can see some performance hits, and should be disabled in production.

::: danger
Zap only checks types that cannot be statically checked by Luau or TypeScript.

For example, Zap will not check if a `string (20)` is a string, but it will check that the string is 20 characters long.
:::

### Default

`false`

### Options

- `true`
- `false`

### Example

<CodeBlock code="opt write_checks = true" />

## `typescript`

This option determines if Zap should generate TypeScript definition files alongside generated Luau code.

When enabled, Zap will generate a `.d.ts` file for the server and client with the same paths as the generated Luau server and client.

### Default

`false`

### Options

- `true`
- `false`

### Example

<CodeBlock code="opt typescript = true" />
